@@ -24,8 +24,11 @@
 #include "config.h"
 
 #include <stdio.h>
+#ifdef HAVE_GETPWUID
 #include <pwd.h>
+#endif
 #include <signal.h>
+#include <fcntl.h>
 
 #include "libs/fvwmlib.h"
 #include "fvwm.h"
@@ -147,13 +150,30 @@ static void setRealStateFilename(char *filename)
 static char *getUniqueStateFilename(void)
 {
   const char *path = getenv("SM_SAVE_DIR");
-  struct passwd *pwd;
+  char *filename;
+  int fd;
 
+  if ( ! path)
+    path = getenv ("HOME");
+
+#ifdef HAVE_GETPWUID
   if (!path) {
-    pwd = getpwuid(getuid());
-    path = pwd->pw_dir;
+    struct passwd *pwd = getpwuid(getuid());
+    if (pwd)
+      path = pwd->pw_dir;
   }
-  return tempnam(path, ".fs-");
+#endif
+  if ( ! path)
+    return NULL;
+
+  filename = tempnam(path, ".fs-");
+  if ((fd = open (filename, O_WRONLY | O_EXCL | O_CREAT, 0600)) == -1) {
+    free (filename);
+    filename = NULL;
+  } else {
+    close (fd);
+  }
+  return filename;
 }
 
 #else
@@ -394,8 +414,9 @@ SaveWindowStates(FILE *f)
   rectangle save_g;
   int i;
 
-  for (ewin = Scr.FvwmRoot.stack_next; ewin != &Scr.FvwmRoot;
-       ewin = ewin->stack_next)
+  for (ewin = get_next_window_in_stack_ring(&Scr.FvwmRoot);
+       ewin != &Scr.FvwmRoot;
+       ewin = get_next_window_in_stack_ring(ewin))
   {
     Bool is_icon_sticky;
 
